Class: Jekyll::Post

Inherits:
Object
  • Object
show all
Includes:
Comparable, Convertible
Defined in:
lib/jekyll/post.rb

Constant Summary collapse

MATCHER =
/^(.+\/)*(\d+-\d+-\d+)-(.*)(\.[^.]+)$/

Class Attribute Summary collapse

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Convertible

#content_type, #do_layout, #read_yaml, #to_s, #transform

Constructor Details

#initialize(site, source, dir, name) ⇒ Post

Initialize this Post instance. site is the Site base is the String path to the dir containing the post file name is the String filename of the post file categories is an Array of Strings for the categories for this post

Returns



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/jekyll/post.rb', line 35

def initialize(site, source, dir, name)
  @site = site
  @base = File.join(source, dir, '_posts')
  @name = name

  self.categories = dir.split('/').reject { |x| x.empty? }
  self.process(name)
  self.read_yaml(@base, name)

  if self.data.has_key?('published') && self.data['published'] == false
    self.published = false
  else
    self.published = true
  end

  if self.data.has_key?("tag")
    self.tags = [self.data["tag"]]
  elsif self.data.has_key?("tags")
    self.tags = self.data['tags']
  else
    self.tags = []
  end

  if self.categories.empty?
    if self.data.has_key?('category')
      self.categories << self.data['category']
    elsif self.data.has_key?('categories')
      # Look for categories in the YAML-header, either specified as
      # an array or a string.
      if self.data['categories'].kind_of? String
        self.categories = self.data['categories'].split
      else
        self.categories = self.data['categories']
      end
    end
  end
end

Class Attribute Details

.lsiObject

Returns the value of attribute lsi.



8
9
10
# File 'lib/jekyll/post.rb', line 8

def lsi
  @lsi
end

Instance Attribute Details

#categoriesObject



24
25
26
# File 'lib/jekyll/post.rb', line 24

def categories
  @categories ||= []
end

#contentObject

Returns the value of attribute content.



21
22
23
# File 'lib/jekyll/post.rb', line 21

def content
  @content
end

#dataObject

Returns the value of attribute data.



21
22
23
# File 'lib/jekyll/post.rb', line 21

def data
  @data
end

#dateObject

Returns the value of attribute date.



21
22
23
# File 'lib/jekyll/post.rb', line 21

def date
  @date
end

#extObject

Returns the value of attribute ext.



21
22
23
# File 'lib/jekyll/post.rb', line 21

def ext
  @ext
end

#outputObject

Returns the value of attribute output.



21
22
23
# File 'lib/jekyll/post.rb', line 21

def output
  @output
end

#publishedObject

Returns the value of attribute published.



21
22
23
# File 'lib/jekyll/post.rb', line 21

def published
  @published
end

#siteObject

Returns the value of attribute site.



21
22
23
# File 'lib/jekyll/post.rb', line 21

def site
  @site
end

#slugObject

Returns the value of attribute slug.



21
22
23
# File 'lib/jekyll/post.rb', line 21

def slug
  @slug
end

#tagsObject

Returns the value of attribute tags.



21
22
23
# File 'lib/jekyll/post.rb', line 21

def tags
  @tags
end

Class Method Details

.valid?(name) ⇒ Boolean

Post name validator. Post filenames must be like:

2008-11-05-my-awesome-post.textile

Returns

Returns:

  • (Boolean)


17
18
19
# File 'lib/jekyll/post.rb', line 17

def self.valid?(name)
  name =~ MATCHER
end

Instance Method Details

#<=>(other) ⇒ Object

Spaceship is based on Post#date, slug

Returns -1, 0, 1



76
77
78
79
80
81
82
# File 'lib/jekyll/post.rb', line 76

def <=>(other)
  cmp = self.date <=> other.date
  if 0 == cmp
   cmp = self.slug <=> other.slug
  end
  return cmp
end

#dirObject

The generated directory into which the post will be placed upon generation. This is derived from the permalink or, if permalink is absent, set to the default date e.g. "/2008/11/05/" if the permalink style is :date, otherwise nothing

Returns



101
102
103
# File 'lib/jekyll/post.rb', line 101

def dir
  File.dirname(url)
end

#idObject

The UID for this post (useful in feeds) e.g. /2008/11/05/my-awesome-post

Returns



149
150
151
# File 'lib/jekyll/post.rb', line 149

def id
  File.join(self.dir, self.slug)
end

#inspectObject



244
245
246
# File 'lib/jekyll/post.rb', line 244

def inspect
  "<Post: #{self.id}>"
end

#nextObject



248
249
250
251
252
253
254
255
256
# File 'lib/jekyll/post.rb', line 248

def next
  pos = self.site.posts.index(self)

  if pos && pos < self.site.posts.length-1
    self.site.posts[pos+1]
  else
    nil
  end
end

The full path and filename of the post. Defined in the YAML of the post body (Optional)

Returns



110
111
112
# File 'lib/jekyll/post.rb', line 110

def permalink
  self.data && self.data['permalink']
end

#previousObject



258
259
260
261
262
263
264
265
# File 'lib/jekyll/post.rb', line 258

def previous
  pos = self.site.posts.index(self)
  if pos && pos > 0
    self.site.posts[pos-1]
  else
    nil
  end
end

#process(name) ⇒ Object

Extract information from the post filename name is the String filename of the post file

Returns nothing



88
89
90
91
92
93
# File 'lib/jekyll/post.rb', line 88

def process(name)
  m, cats, date, slug, ext = *name.match(MATCHER)
  self.date = Time.parse(date)
  self.slug = slug
  self.ext = ext
end

Calculate related posts.

Returns []



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/jekyll/post.rb', line 156

def related_posts(posts)
  return [] unless posts.size > 1

  if self.site.lsi
    self.class.lsi ||= begin
      puts "Running the classifier... this could take a while."
      lsi = Classifier::LSI.new
      posts.each { |x| $stdout.print(".");$stdout.flush;lsi.add_item(x) }
      puts ""
      lsi
    end

    related = self.class.lsi.find_related(self.content, 11)
    related - [self]
  else
    (posts - [self])[0..9]
  end
end

#render(layouts, site_payload) ⇒ Object

Add any necessary layouts to this post layouts is a Hash of => "layout" site_payload is the site payload hash

Returns nothing



180
181
182
183
184
185
186
187
188
189
190
# File 'lib/jekyll/post.rb', line 180

def render(layouts, site_payload)
  # construct payload
  payload =
  {
    "site" => { "related_posts" => related_posts(site_payload["site"]["posts"]) },
    "page" => self.to_liquid
  }
  payload = payload.deep_merge(site_payload)

  do_layout(payload, layouts)
end

#templateObject



114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/jekyll/post.rb', line 114

def template
  case self.site.permalink_style
  when :pretty
    "/:categories/:year/:month/:day/:title/"
  when :none
    "/:categories/:title.html"
  when :date
    "/:categories/:year/:month/:day/:title.html"
  else
    self.site.permalink_style.to_s
  end
end

#to_liquidObject

Convert this post into a Hash for use in Liquid templates.

Returns



232
233
234
235
236
237
238
239
240
241
242
# File 'lib/jekyll/post.rb', line 232

def to_liquid
  { "title"      => self.data["title"] || self.slug.split('-').select {|w| w.capitalize! || w }.join(' '),
    "url"        => self.url,
    "date"       => self.date,
    "id"         => self.id,
    "categories" => self.categories,
    "next"       => self.next,
    "previous"   => self.previous,
    "tags"       => self.tags,
    "content"    => self.content }.deep_merge(self.data)
end

#urlObject

The generated relative url of this post e.g. /2008/11/05/my-awesome-post.html

Returns



131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/jekyll/post.rb', line 131

def url
  return permalink if permalink

  @url ||= {
    "year"       => date.strftime("%Y"),
    "month"      => date.strftime("%m"),
    "day"        => date.strftime("%d"),
    "title"      => CGI.escape(slug),
    "categories" => categories.sort.join('/')
  }.inject(template) { |result, token|
    result.gsub(/:#{token.first}/, token.last)
  }.gsub(/\/\//, "/")
end

#write(dest) ⇒ Object

Write the generated post file to the destination directory. dest is the String path to the destination dir

Returns nothing



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/jekyll/post.rb', line 196

def write(dest)
  FileUtils.mkdir_p(File.join(dest, dir))

  # The url needs to be unescaped in order to preserve the correct filename
  path = File.join(dest, CGI.unescape(self.url))

  # Write the post's files out into a directory named after the post
  self.write_postfiles(path) if self.site.config['postfiles']

  if template[/\.html$/].nil?
    FileUtils.mkdir_p(path)
    path = File.join(path, "index.html")
  end

  File.open(path, 'w') do |f|
    f.write(self.output)
  end
end

#write_postfiles(dest) ⇒ Object

Write the files that the post depends on into its directory

Returns nothing



219
220
221
222
223
224
225
226
# File 'lib/jekyll/post.rb', line 219

def write_postfiles(dest)
  glob = File.join("./_postfiles", File.basename(@name, File.extname(@name)), "*")
  postfiles = Dir[glob]
  if postfiles.any?
    FileUtils.mkdir_p(dest)
    postfiles.each{|pf| FileUtils.cp(pf, dest) }
  end
end